@@ -134,8 +134,6 @@ KateCompletionModel::KateCompletionModel(KateCompletionWidget *parent)
     , m_ungrouped(new Group({}, 0, this))
     , m_argumentHints(new Group(i18n("Argument-hints"), -1, this))
     , m_bestMatches(new Group(i18n("Best matches"), BestMatchesProperty, this))
-    , m_filterAttributes(KTextEditor::CodeCompletionModel::NoProperty)
-
 {
     m_emptyGroups.append(m_ungrouped);
     m_emptyGroups.append(m_argumentHints);
@@ -1249,23 +1247,6 @@ bool KateCompletionModel::hasCompletionModel() const
     return !m_completionModels.isEmpty();
 }
 
-void KateCompletionModel::setFilteringEnabled(bool enable)
-{
-    if (m_filteringEnabled != enable) {
-        m_filteringEnabled = enable;
-    }
-}
-
-void KateCompletionModel::setSortingEnabled(bool enable)
-{
-    if (m_sortingEnabled != enable) {
-        m_sortingEnabled = enable;
-        beginResetModel();
-        resort();
-        endResetModel();
-    }
-}
-
 void KateCompletionModel::setGroupingEnabled(bool enable)
 {
     if (m_groupingEnabled != enable) {
@@ -1290,16 +1271,6 @@ bool KateCompletionModel::isGroupingEnabled() const
     return m_groupingEnabled;
 }
 
-bool KateCompletionModel::isFilteringEnabled() const
-{
-    return m_filteringEnabled;
-}
-
-bool KateCompletionModel::isSortingEnabled() const
-{
-    return m_sortingEnabled;
-}
-
 QString KateCompletionModel::columnName(int column)
 {
     switch (column) {
@@ -1503,30 +1474,10 @@ KateCompletionModel::GroupingMethods KateCompletionModel::groupingMethod() const
     return m_groupingMethod;
 }
 
-bool KateCompletionModel::isSortingByInheritanceDepth() const
-{
-    return m_isSortingByInheritance;
-}
-void KateCompletionModel::setSortingByInheritanceDepth(bool byInheritance)
-{
-    m_isSortingByInheritance = byInheritance;
-}
-
-bool KateCompletionModel::isSortingAlphabetical() const
-{
-    return m_sortingAlphabetical;
-}
-
-Qt::CaseSensitivity KateCompletionModel::sortingCaseSensitivity() const
-{
-    return m_sortingCaseSensitivity;
-}
-
 KateCompletionModel::Item::Item(bool doInitialMatch, KateCompletionModel *m, const HierarchicalModelHandler &handler, ModelRow sr)
     : model(m)
     , m_sourceRow(sr)
     , matchCompletion(StartsWithMatch)
-    , matchFilters(true)
     , m_haveExactMatch(false)
 {
     inheritanceDepth = handler.getData(CodeCompletionModel::InheritanceDepth, m_sourceRow.second).toInt();
@@ -1536,7 +1487,6 @@ KateCompletionModel::Item::Item(bool doInitialMatch, KateCompletionModel *m, con
     m_nameColumn = nameSibling.data(Qt::DisplayRole).toString();
 
     if (doInitialMatch) {
-        filter();
         match();
     }
 }
@@ -1576,13 +1526,11 @@ bool KateCompletionModel::Item::operator<(const Item &rhs) const
         }
     }
 
-    if (model->isSortingByInheritanceDepth()) {
-        ret = inheritanceDepth - rhs.inheritanceDepth;
-    }
+    ret = inheritanceDepth - rhs.inheritanceDepth;
 
-    if (ret == 0 && model->isSortingAlphabetical()) {
+    if (ret == 0) {
         // Do not use localeAwareCompare, because it is simply too slow for a list of about 1000 items
-        ret = QString::compare(m_nameColumn, rhs.m_nameColumn, model->sortingCaseSensitivity());
+        ret = QString::compare(m_nameColumn, rhs.m_nameColumn, Qt::CaseInsensitive);
     }
 
     if (ret == 0) {
@@ -1604,25 +1552,16 @@ void KateCompletionModel::Group::addItem(const Item &i, bool notifyModel)
         groupIndex = model->indexForGroup(this);
     }
 
-    if (model->isSortingEnabled()) {
-        prefilter.insert(std::upper_bound(prefilter.begin(), prefilter.end(), i), i);
-        if (i.isVisible()) {
-            QList<Item>::iterator it = std::upper_bound(filtered.begin(), filtered.end(), i);
-            uint rowNumber = it - filtered.begin();
+    prefilter.insert(std::upper_bound(prefilter.begin(), prefilter.end(), i), i);
+    if (i.isVisible()) {
+        QList<Item>::iterator it = std::upper_bound(filtered.begin(), filtered.end(), i);
+        uint rowNumber = it - filtered.begin();
 
-            if (notifyModel) {
-                model->beginInsertRows(groupIndex, rowNumber, rowNumber);
-            }
-
-            filtered.insert(it, i);
-        }
-    } else {
         if (notifyModel) {
-            model->beginInsertRows(groupIndex, prefilter.size(), prefilter.size());
-        }
-        if (i.isVisible()) {
-            prefilter.append(i);
+            model->beginInsertRows(groupIndex, rowNumber, rowNumber);
         }
+
+        filtered.insert(it, i);
     }
 
     if (notifyModel) {
@@ -1664,32 +1603,12 @@ KateCompletionModel::Group::Group(const QString &title, int attribute, KateCompl
     Q_ASSERT(model);
 }
 
-void KateCompletionModel::setSortingAlphabetical(bool alphabetical)
-{
-    if (m_sortingAlphabetical != alphabetical) {
-        m_sortingAlphabetical = alphabetical;
-        beginResetModel();
-        resort();
-        endResetModel();
-    }
-}
-
 void KateCompletionModel::Group::resort()
 {
     std::stable_sort(filtered.begin(), filtered.end());
     model->hideOrShowGroup(this);
 }
 
-void KateCompletionModel::setSortingCaseSensitivity(Qt::CaseSensitivity cs)
-{
-    if (m_sortingCaseSensitivity != cs) {
-        m_sortingCaseSensitivity = cs;
-        beginResetModel();
-        resort();
-        endResetModel();
-    }
-}
-
 void KateCompletionModel::resort()
 {
     for (Group *g : qAsConst(m_rowTable)) {
@@ -1716,124 +1635,6 @@ void KateCompletionModel::Group::clear()
     isEmpty = true;
 }
 
-bool KateCompletionModel::filterContextMatchesOnly() const
-{
-    return m_filterContextMatchesOnly;
-}
-
-void KateCompletionModel::setFilterContextMatchesOnly(bool filter)
-{
-    if (m_filterContextMatchesOnly != filter) {
-        m_filterContextMatchesOnly = filter;
-        refilter();
-    }
-}
-
-bool KateCompletionModel::filterByAttribute() const
-{
-    return m_filterByAttribute;
-}
-
-void KateCompletionModel::setFilterByAttribute(bool filter)
-{
-    if (m_filterByAttribute == filter) {
-        m_filterByAttribute = filter;
-        refilter();
-    }
-}
-
-KTextEditor::CodeCompletionModel::CompletionProperties KateCompletionModel::filterAttributes() const
-{
-    return m_filterAttributes;
-}
-
-void KateCompletionModel::setFilterAttributes(KTextEditor::CodeCompletionModel::CompletionProperties attributes)
-{
-    if (m_filterAttributes == attributes) {
-        m_filterAttributes = attributes;
-        refilter();
-    }
-}
-
-int KateCompletionModel::maximumInheritanceDepth() const
-{
-    return m_maximumInheritanceDepth;
-}
-
-void KateCompletionModel::setMaximumInheritanceDepth(int maxDepth)
-{
-    if (m_maximumInheritanceDepth != maxDepth) {
-        m_maximumInheritanceDepth = maxDepth;
-        refilter();
-    }
-}
-
-void KateCompletionModel::refilter()
-{
-    beginResetModel();
-    m_ungrouped->refilter();
-
-    for (Group *g : qAsConst(m_rowTable)) {
-        if (g != m_argumentHints) {
-            g->refilter();
-        }
-    }
-
-    for (Group *g : qAsConst(m_emptyGroups)) {
-        if (g != m_argumentHints) {
-            g->refilter();
-        }
-    }
-
-    updateBestMatches();
-
-    clearExpanding(); // We need to do this, or be aware of expanding-widgets while filtering.
-    endResetModel();
-}
-
-void KateCompletionModel::Group::refilter()
-{
-    filtered.clear();
-    for (const Item &i : qAsConst(prefilter)) {
-        if (!i.isFiltered()) {
-            filtered.append(i);
-        }
-    }
-}
-
-bool KateCompletionModel::Item::filter()
-{
-    matchFilters = false;
-
-    if (model->isFilteringEnabled()) {
-        QModelIndex sourceIndex = m_sourceRow.second.sibling(m_sourceRow.second.row(), CodeCompletionModel::Name);
-
-        if (model->filterContextMatchesOnly()) {
-            QVariant contextMatch = sourceIndex.data(CodeCompletionModel::MatchQuality);
-            if (contextMatch.canConvert(QVariant::Int) && !contextMatch.toInt()) {
-                return false;
-            }
-        }
-
-        if (model->filterByAttribute()) {
-            int completionFlags = sourceIndex.data(CodeCompletionModel::CompletionRole).toInt();
-            if (model->filterAttributes() & completionFlags) {
-                return false;
-            }
-        }
-
-        if (model->maximumInheritanceDepth() > 0) {
-            int inheritanceDepth = sourceIndex.data(CodeCompletionModel::InheritanceDepth).toInt();
-            if (inheritanceDepth > model->maximumInheritanceDepth()) {
-                return false;
-            }
-        }
-    }
-
-    matchFilters = true;
-    return matchFilters;
-}
-
 uint KateCompletionModel::filteredItemCount() const
 {
     uint ret = 0;
@@ -2117,17 +1918,7 @@ QString KateCompletionModel::propertyName(KTextEditor::CodeCompletionModel::Comp
 
 bool KateCompletionModel::Item::isVisible() const
 {
-    return matchCompletion && matchFilters;
-}
-
-bool KateCompletionModel::Item::isFiltered() const
-{
-    return !matchFilters;
-}
-
-bool KateCompletionModel::Item::isMatching() const
-{
-    return matchFilters;
+    return matchCompletion;
 }
 
 const KateCompletionModel::ModelRow &KateCompletionModel::Item::sourceRow() const
