@@ -49,9 +49,7 @@ KateBuffer::KateBuffer(KTextEditor::DocumentPrivate *doc)
 /**
  * Cleanup on destruction
  */
-KateBuffer::~KateBuffer()
-{
-}
+KateBuffer::~KateBuffer() = default;
 
 void KateBuffer::editStart()
 {
@@ -397,10 +395,11 @@ void KateBuffer::doHighlight(int startLine, int endLine, bool invalidate)
         qCDebug(LOG_KTE) << "HIGHLIGHTED TAG LINES: " << startLine << current_line;
 #endif
 
-        emit tagLines(startLine, qMax(current_line, oldHighlighted));
+        Q_EMIT tagLines({startLine, qMax(current_line, oldHighlighted)});
 
         if (start_spellchecking >= 0 && lines() > 0) {
-            emit respellCheckBlock(start_spellchecking, qMin(lines() - 1, (last_line_spellchecking == -1) ? qMax(current_line, oldHighlighted) : last_line_spellchecking));
+            Q_EMIT respellCheckBlock(start_spellchecking,
+                                     qMin(lines() - 1, (last_line_spellchecking == -1) ? qMax(current_line, oldHighlighted) : last_line_spellchecking));
         }
     }
 
