@@ -42,6 +42,7 @@
 #include <QClipboard>
 #include <QPushButton>
 #include <QStringListModel>
+#include <QTimer>
 
 #if LIBGIT2_FOUND
 #include <git2.h>
@@ -68,7 +69,7 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
                   QStringLiteral(KTEXTEDITOR_VERSION_STRING),
                   i18n("Embeddable editor component"),
                   KAboutLicense::LGPL_V2,
-                  i18n("(c) 2000-2020 The Kate Authors"),
+                  i18n("(c) 2000-2021 The Kate Authors"),
                   QString(),
                   QStringLiteral("https://kate-editor.org"))
     , m_dummyApplication(nullptr)
@@ -96,9 +97,15 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
     m_aboutData.addAuthor(i18n("Christoph Cullmann"), i18n("Maintainer"), QStringLiteral("cullmann@kde.org"), QStringLiteral("https://cullmann.io"));
     m_aboutData.addAuthor(i18n("Dominik Haumann"), i18n("Core Developer"), QStringLiteral("dhaumann@kde.org"));
     m_aboutData.addAuthor(i18n("Milian Wolff"), i18n("Core Developer"), QStringLiteral("mail@milianw.de"), QStringLiteral("https://milianw.de/"));
-    m_aboutData.addAuthor(i18n("Joseph Wenninger"), i18n("Core Developer"), QStringLiteral("jowenn@kde.org"), QStringLiteral("http://stud3.tuwien.ac.at/~e9925371"));
+    m_aboutData.addAuthor(i18n("Joseph Wenninger"),
+                          i18n("Core Developer"),
+                          QStringLiteral("jowenn@kde.org"),
+                          QStringLiteral("http://stud3.tuwien.ac.at/~e9925371"));
     m_aboutData.addAuthor(i18n("Erlend Hamberg"), i18n("Vi Input Mode"), QStringLiteral("ehamberg@gmail.com"), QStringLiteral("https://hamberg.no/erlend"));
-    m_aboutData.addAuthor(i18n("Bernhard Beschow"), i18n("Developer"), QStringLiteral("bbeschow@cs.tu-berlin.de"), QStringLiteral("https://user.cs.tu-berlin.de/~bbeschow"));
+    m_aboutData.addAuthor(i18n("Bernhard Beschow"),
+                          i18n("Developer"),
+                          QStringLiteral("bbeschow@cs.tu-berlin.de"),
+                          QStringLiteral("https://user.cs.tu-berlin.de/~bbeschow"));
     m_aboutData.addAuthor(i18n("Anders Lund"), i18n("Core Developer"), QStringLiteral("anders@alweb.dk"), QStringLiteral("https://alweb.dk"));
     m_aboutData.addAuthor(i18n("Michel Ludwig"), i18n("On-the-fly spell checking"), QStringLiteral("michel.ludwig@kdemail.net"));
     m_aboutData.addAuthor(i18n("Pascal Létourneau"), i18n("Large scale bug fixing"), QStringLiteral("pascal.letourneau@gmail.com"));
@@ -117,9 +124,15 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
     m_aboutData.addAuthor(i18n("Andreas Kling"), i18n("Developer"), QStringLiteral("kling@impul.se"));
     m_aboutData.addAuthor(i18n("Mirko Stocker"), i18n("Various bugfixes"), QStringLiteral("me@misto.ch"), QStringLiteral("https://misto.ch/"));
     m_aboutData.addAuthor(i18n("Matthew Woehlke"), i18n("Selection, KColorScheme integration"), QStringLiteral("mw_triad@users.sourceforge.net"));
-    m_aboutData.addAuthor(i18n("Sebastian Pipping"), i18n("Search bar back- and front-end"), QStringLiteral("webmaster@hartwork.org"), QStringLiteral("https://hartwork.org/"));
+    m_aboutData.addAuthor(i18n("Sebastian Pipping"),
+                          i18n("Search bar back- and front-end"),
+                          QStringLiteral("webmaster@hartwork.org"),
+                          QStringLiteral("https://hartwork.org/"));
     m_aboutData.addAuthor(i18n("Jochen Wilhelmy"), i18n("Original KWrite Author"), QStringLiteral("digisnap@cs.tu-berlin.de"));
-    m_aboutData.addAuthor(i18n("Gerald Senarclens de Grancy"), i18n("QA and Scripting"), QStringLiteral("oss@senarclens.eu"), QStringLiteral("http://find-santa.eu/"));
+    m_aboutData.addAuthor(i18n("Gerald Senarclens de Grancy"),
+                          i18n("QA and Scripting"),
+                          QStringLiteral("oss@senarclens.eu"),
+                          QStringLiteral("http://find-santa.eu/"));
 
     m_aboutData.addCredit(i18n("Matteo Merli"), i18n("Highlighting for RPM Spec-Files, Perl, Diff and more"), QStringLiteral("merlim@libero.it"));
     m_aboutData.addCredit(i18n("Rocky Scaletta"), i18n("Highlighting for VHDL"), QStringLiteral("rocky@purdue.edu"));
@@ -170,14 +183,9 @@ KTextEditor::EditorPrivate::EditorPrivate(QPointer<KTextEditor::EditorPrivate> &
     //
     // input mode factories
     //
-    KateAbstractInputModeFactory *fact;
-    fact = new KateNormalInputModeFactory();
-    m_inputModeFactories.insert(KTextEditor::View::NormalInputMode, fact);
-
-#if BUILD_VIMODE
-    fact = new KateViInputModeFactory();
-    m_inputModeFactories.insert(KTextEditor::View::ViInputMode, fact);
-#endif
+    Q_ASSERT(m_inputModeFactories.size() == KTextEditor::View::ViInputMode + 1);
+    m_inputModeFactories[KTextEditor::View::NormalInputMode].reset(new KateNormalInputModeFactory());
+    m_inputModeFactories[KTextEditor::View::ViInputMode].reset(new KateViInputModeFactory());
 
     //
     // spell check manager
@@ -240,8 +248,6 @@ KTextEditor::EditorPrivate::~EditorPrivate()
     qDeleteAll(m_cmds);
     delete m_cmdManager;
 
-    qDeleteAll(m_inputModeFactories);
-
     // shutdown libgit2, we require at least 0.22 which has this function!
 #if LIBGIT2_FOUND
     git_libgit2_shutdown();
@@ -252,7 +258,7 @@ KTextEditor::Document *KTextEditor::EditorPrivate::createDocument(QObject *paren
 {
     KTextEditor::DocumentPrivate *doc = new KTextEditor::DocumentPrivate(false, false, nullptr, parent);
 
-    emit documentCreated(this, doc);
+    Q_EMIT documentCreated(this, doc);
 
     return doc;
 }
@@ -280,7 +286,7 @@ void KTextEditor::EditorPrivate::configDialog(QWidget *parent)
         QVBoxLayout *topLayout = new QVBoxLayout(page);
         topLayout->setContentsMargins(0, 0, 0, 0);
 
-        connect(kd->button(QDialogButtonBox::Apply), SIGNAL(clicked()), cp, SLOT(apply()));
+        connect(kd->button(QDialogButtonBox::Apply), &QPushButton::clicked, cp, &KTextEditor::ConfigPage::apply);
         topLayout->addWidget(cp);
         editorPages.append(cp);
     }
@@ -438,7 +444,7 @@ void KTextEditor::EditorPrivate::copyToClipboard(const QString &text)
     }
 
     // notify about change
-    emit clipboardHistoryChanged();
+    Q_EMIT clipboardHistoryChanged();
 }
 
 bool KTextEditor::EditorPrivate::eventFilter(QObject *obj, QEvent *event)
@@ -451,11 +457,6 @@ bool KTextEditor::EditorPrivate::eventFilter(QObject *obj, QEvent *event)
     return false; // always continue processing
 }
 
-QList<KateAbstractInputModeFactory *> KTextEditor::EditorPrivate::inputModeFactories()
-{
-    return m_inputModeFactories.values();
-}
-
 QStringListModel *KTextEditor::EditorPrivate::searchHistoryModel()
 {
     if (!m_searchHistoryModel) {
@@ -506,3 +507,19 @@ KSharedConfigPtr KTextEditor::EditorPrivate::config()
     }
     return applicationConfig;
 }
+
+void KTextEditor::EditorPrivate::triggerConfigChanged()
+{
+    // trigger delayed emission, will collapse multiple events to one signal emission
+    m_configWasChanged = true;
+    QTimer::singleShot(0, this, &KTextEditor::EditorPrivate::emitConfigChanged);
+}
+
+void KTextEditor::EditorPrivate::emitConfigChanged()
+{
+    // emit only once, if still needed
+    if (m_configWasChanged) {
+        m_configWasChanged = false;
+        Q_EMIT configChanged(this);
+    }
+}
