@@ -1,29 +1,13 @@
-/* This file is part of the KDE libraries
+/*
+    SPDX-FileCopyrightText: 2015 Michal Humpula <michal.humpula@hudrydum.cz>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02111-13020, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "wordcounter.h"
 #include "katedocument.h"
 #include "kateview.h"
 
-namespace
-{
-const int MaximumLinesToRecalculate = 100;
-}
-
 WordCounter::WordCounter(KTextEditor::ViewPrivate *view)
     : QObject(view)
     , m_wordsInDocument(0)
@@ -47,11 +31,11 @@ WordCounter::WordCounter(KTextEditor::ViewPrivate *view)
 
 void WordCounter::textInserted(KTextEditor::Document *, const KTextEditor::Range &range)
 {
-    const int startLine = range.start().line();
-    const int endLine = range.end().line();
-    int newLines = endLine - startLine;
+    auto startLine = m_countByLine.begin() + range.start().line();
+    auto endLine = m_countByLine.begin() + range.end().line();
+    size_t newLines = std::distance(startLine, endLine);
 
-    if (m_countByLine.count() == 0) { // was empty document before insert
+    if (m_countByLine.empty()) { // was empty document before insert
         newLines++;
     }
 
@@ -59,39 +43,60 @@ void WordCounter::textInserted(KTextEditor::Document *, const KTextEditor::Range
         m_countByLine.insert(startLine, newLines, -1);
     }
 
-    m_countByLine[endLine] = -1;
+    m_countByLine[range.end().line()] = -1;
     m_timer.start();
 }
 
 void WordCounter::textRemoved(KTextEditor::Document *, const KTextEditor::Range &range, const QString &)
 {
-    const int startLine = range.start().line();
-    const int endLine = range.end().line();
+    const auto startLine = m_countByLine.begin() + range.start().line();
+    const auto endLine = m_countByLine.begin() + range.end().line();
     const int removedLines = endLine - startLine;
 
     if (removedLines > 0) {
-        m_countByLine.remove(startLine, removedLines);
+        m_countByLine.erase(startLine, endLine);
     }
 
-    if (!m_countByLine.isEmpty()) {
-        m_countByLine[startLine] = -1;
+    if (!m_countByLine.empty()) {
+        m_countByLine[range.start().line()] = -1;
         m_timer.start();
     } else {
-        emit changed(0, 0, 0, 0);
+        Q_EMIT changed(0, 0, 0, 0);
     }
 }
 
 void WordCounter::recalculate(KTextEditor::Document *)
 {
-    m_countByLine = QVector<int>(m_document->lines(), -1);
+    m_countByLine = std::vector<int>(m_document->lines(), -1);
     m_timer.start();
 }
 
+static int countWords(const QString &text)
+{
+    int count = 0;
+    bool inWord = false;
+
+    for (const QChar c : text) {
+        if (c.isLetterOrNumber()) {
+            if (!inWord) {
+                inWord = true;
+            }
+        } else {
+            if (inWord) {
+                inWord = false;
+                count++;
+            }
+        }
+    }
+
+    return inWord ? count + 1 : count;
+}
+
 void WordCounter::selectionChanged(KTextEditor::View *view)
 {
     if (view->selectionRange().isEmpty()) {
         m_wordsInSelection = m_charsInSelection = 0;
-        emit changed(m_wordsInDocument, 0, m_charsInDocument, 0);
+        Q_EMIT changed(m_wordsInDocument, 0, m_charsInDocument, 0);
         return;
     }
 
@@ -122,18 +127,19 @@ void WordCounter::selectionChanged(KTextEditor::View *view)
         m_charsInSelection += lastLineText.size();
     }
 
-    emit changed(m_wordsInDocument, m_wordsInSelection, m_charsInDocument, m_charsInSelection);
+    Q_EMIT changed(m_wordsInDocument, m_wordsInSelection, m_charsInDocument, m_charsInSelection);
 }
 
 void WordCounter::recalculateLines()
 {
-    if (m_startRecalculationFrom >= m_countByLine.size()) {
+    if ((size_t)m_startRecalculationFrom >= m_countByLine.size()) {
         m_startRecalculationFrom = 0;
     }
 
     int wordsCount = 0, charsCount = 0;
     int calculated = 0;
-    int i = m_startRecalculationFrom;
+    size_t i = m_startRecalculationFrom;
+    constexpr int MaximumLinesToRecalculate = 100;
 
     // stay in bounds, vector might be empty, even 0 is too large then
     while (i < m_countByLine.size()) {
@@ -153,33 +159,12 @@ void WordCounter::recalculateLines()
             i = 0;
         }
 
-        if (i == m_startRecalculationFrom) {
+        if (i == (size_t)m_startRecalculationFrom) {
             break;
         }
     }
 
     m_wordsInDocument = wordsCount;
     m_charsInDocument = charsCount;
-    emit changed(m_wordsInDocument, m_wordsInSelection, m_charsInDocument, m_charsInSelection);
-}
-
-int WordCounter::countWords(const QString &text) const
-{
-    int count = 0;
-    bool inWord = false;
-
-    for (const QChar &c : text) {
-        if (c.isLetterOrNumber()) {
-            if (!inWord) {
-                inWord = true;
-            }
-        } else {
-            if (inWord) {
-                inWord = false;
-                count++;
-            }
-        }
-    }
-
-    return (inWord) ? count + 1 : count;
+    Q_EMIT changed(m_wordsInDocument, m_wordsInSelection, m_charsInDocument, m_charsInSelection);
 }
